@@ -2,37 +2,35 @@ use anyhow::Result;
 use structopt::{self, StructOpt};
 
 mod config;
-mod extension;
+mod extensions;
 mod lock;
 mod pay;
-mod payee;
 mod price;
+mod profile;
+mod service;
 
 #[derive(Debug, StructOpt, Clone)]
 pub enum Command {
     /// Price a package and its dependencies.
-    #[structopt(name = "price")]
     Price(price::Arguments),
 
     /// Pay fees or donations to project dependencies.
-    #[structopt(name = "pay")]
     Pay(pay::Arguments),
 
-    /// Manage payee profiles.
-    #[structopt(name = "payee")]
-    Payee(payee::Arguments),
+    /// Manage profile.
+    Profile(profile::Arguments),
 
     /// Manage lock file.
-    #[structopt(name = "lock")]
     Lock(lock::Arguments),
 
+    /// Manage payment services.
+    Service(service::Arguments),
+
     /// Configure settings.
-    #[structopt(name = "config")]
     Config(config::Arguments),
 
     /// Manage extensions.
-    #[structopt(name = "extension")]
-    Extension(extension::Arguments),
+    Extensions(extensions::Arguments),
 }
 
 pub fn run_command(command: Command, extension_args: &Vec<String>) -> Result<()> {
@@ -45,17 +43,20 @@ pub fn run_command(command: Command, extension_args: &Vec<String>) -> Result<()>
         Command::Pay(args) => {
             pay::run_command(&args, &extension_args)?;
         }
-        Command::Payee(args) => {
-            payee::run_command(&args)?;
+        Command::Profile(args) => {
+            profile::run_command(&args)?;
         }
         Command::Lock(args) => {
             lock::run_command(&args)?;
         }
+        Command::Service(args) => {
+            service::run_command(&args)?;
+        }
         Command::Config(args) => {
             config::run_command(&args)?;
         }
-        Command::Extension(args) => {
-            extension::run_command(&args)?;
+        Command::Extensions(args) => {
+            extensions::run_command(&args)?;
         }
     }
     Ok(())
