@@ -15,14 +15,26 @@ pub enum AddSubcommands {
 }
 
 pub fn add(subcommand: &AddSubcommands) -> Result<()> {
-    match subcommand {
-        AddSubcommands::PayPal(args) => {
-            paypal::add(&args)?;
-        }
-        AddSubcommands::BtcLightning(args) => {
-            btc_lightning::add(&args)?;
-        }
+    let payment_method = match subcommand {
+        AddSubcommands::PayPal(args) => paypal::add(&args)?,
+        AddSubcommands::BtcLightning(args) => btc_lightning::add(&args)?,
+    };
+
+    #[derive(serde::Serialize)]
+    struct Report {
+        #[serde(flatten)]
+        x: std::collections::BTreeMap<
+            openfare_lib::profile::payment_methods::Methods,
+            serde_json::Value,
+        >,
     }
+    let report = Report {
+        x: maplit::btreemap! {payment_method.method() => payment_method.to_serde_json_value()?},
+    };
+    println!(
+        "Added payment-method:\n{}",
+        serde_json::to_string_pretty(&report)?
+    );
     Ok(())
 }
 
