@@ -22,15 +22,16 @@ pub struct AddArguments {
     pub email: Option<String>,
 }
 
-pub fn add(args: &AddArguments) -> Result<()> {
+pub fn add(
+    args: &AddArguments,
+) -> Result<Box<dyn openfare_lib::profile::payment_methods::PaymentMethod>> {
     let payment_method = Method::new(&args.id, &args.email)?;
+    let payment_method =
+        Box::new(payment_method) as Box<dyn openfare_lib::profile::payment_methods::PaymentMethod>;
     let mut profile = crate::handles::ProfileHandle::load()?;
-    (*profile).set_payment_method(
-        &(Box::new(payment_method)
-            as Box<dyn openfare_lib::profile::payment_methods::PaymentMethod>),
-    )?;
+    (*profile).set_payment_method(&payment_method)?;
     profile.dump()?;
-    Ok(())
+    Ok(payment_method)
 }
 
 #[derive(Debug, StructOpt, Clone)]
