@@ -1,5 +1,4 @@
 use anyhow::{Context, Result};
-pub mod archive;
 
 pub fn ensure_extensions_bin_directory() -> Result<Option<std::path::PathBuf>> {
     // Attempt to create an extensions directory in the users home directory.
@@ -41,7 +40,7 @@ pub fn get_extensions_default_directory() -> Option<std::path::PathBuf> {
 }
 
 #[cfg(windows)]
-fn set_directory_hidden_windows(directory: &std::path::PathBuf) {
+fn set_directory_hidden_windows(_directory: &std::path::PathBuf) {
     // TODO: Hide directory on Windows.
     // winapi::um::fileapi::SetFileAttributesA()
 }
