@@ -3,8 +3,12 @@ use structopt::StructOpt;
 
 mod command;
 mod common;
-mod extension;
+mod config;
+mod extensions;
+mod handles;
+mod payments;
 mod price;
+mod services;
 mod setup;
 
 fn main() {
